
<!--
FrozenIsBool False
-->

#Printer

##Doc
----


> 
> The Printer is an object that can directly print 
> Strs in the Representer context.
> 
> 

----

<small>
View the Printer notebook on [NbViewer](http://nbviewer.ipython.org/url/shareyoursystem.ouvaton.org/Printer.ipynb)
</small>

